Method: Blueprinter::Base.render_as_json

Defined in:
lib/blueprinter/base.rb

.render_as_json(object, options = {}) ⇒ Hash

Generates a JSONified hash. Takes a required object and an optional view.

Examples:

Generating a hash with an extended view

post = Post.all
Blueprinter::Base.render_as_json post, view: :extended
# => [{"id" => "1", "title" => "Hello"},{"id" => "2", "title" => "My Day"}]

Options Hash (options):

  • :view (Symbol)

    Defaults to :default. The view name that corresponds to the group of fields to be serialized.

  • :root (Symbol|String)

    Defaults to nil. Render the json/hash with a root key if provided.

  • :meta (Any)

    Defaults to nil. Render the json/hash with a meta attribute with provided value if both root and meta keys are provided in the options hash.



245
246
247
# File 'lib/blueprinter/base.rb', line 245

def self.render_as_json(object, options = {})
  prepare_for_render(object, options).as_json
end